@@ -21,15 +21,13 @@ class TaskDriver(object):
             kwargs['formatter_class'] = argparse.RawDescriptionHelpFormatter
         self.parser = argparse.ArgumentParser(**kwargs)
         #self.parser.add_argument('--help-commands', dest='help_commands', action='store_true', default=False, help="Print a list of available subcommands")
-        self.subparsers = None
+        self.subparsers = self.parser.add_subparsers(help='Sub-commands', dest='subparser_name')
         self.wf = {}
         
     def register_task(self, wf, name=None, help=''):
-        if self.subparsers is None:
-            self.subparsers = self.parser.add_subparsers(help=help)
         if name is None:
             name=wf
-        ans = tasks.TaskFactory(wf, parser=self.subparsers.add_parser(name))
+        ans = tasks.TaskFactory(wf, parser=self.subparsers.add_parser(name, help=help))
         if ans is None:
             raise ValueError, "Unknown workflow task '%s'\n    Available tasks: %s" % (wf, ' '.join(tasks.TaskFactory().services()))
         ans._parser.set_defaults(subparser_name=name)
@@ -45,21 +43,10 @@ class TaskDriver(object):
         else:
             ret = self.parser.parse_args(args)
         opt = Options()
-        subcmd = None
         for key in dir(ret):
-            if key[0] != '_':
-                if key == 'subparser_name':
-                    subcmd = getattr(ret,key)
-                # Ignore the TaskDriver global options
-                #elif not key in ['help_commands']:
-                else:
-                    opt[key] = getattr(ret,key)
-        #if subcmd is None:
-            #return self.process_core_arguments(opt)
-        if not subcmd in self.wf:
-            self.parser.print_help()
-            return Options()
-        return self.wf[ subcmd ](opt)
+            if key[0] != '_' and key != 'subparser_name':
+                opt[key] = getattr(ret,key)
+        return self.wf[ ret.subparser_name ](opt)
 
     def process_core_arguments(self, opt):
         if opt.help_commands:
