@@ -145,14 +145,14 @@ class Test(unittest.TestCase):
         # Print workflow
         #
         ##print "..."
-        self.failUnlessEqual(str(w),\
+        self.assertEqual(str(w),\
 """Workflow Task4:
 Task5 prev: [] next: [2, 3] resources: []
 Task2 prev: [5] next: [1] resources: []
 Task3 prev: [5] next: [1] resources: []
 Task1 prev: [2, 3] next: [6] resources: []
 Task6 prev: [1] next: [] resources: []""")
-        self.failUnlessEqual(w(i=3, a=2), {'z':334})
+        self.assertEqual(w(i=3, a=2), {'z':334})
 
     def test1c(self):
         pyutilib.workflow.reset_id_counter()
@@ -173,7 +173,7 @@ Task6 prev: [1] next: [] resources: []""")
         # Print workflow
         #
         ##print "..."
-        self.failUnlessEqual(str(w),\
+        self.assertEqual(str(w),\
 """Workflow Task5:
 Task6 prev: [] next: [4] resources: []
 Task4 prev: [6] next: [2, 3] resources: []
@@ -181,7 +181,7 @@ Task2 prev: [4] next: [1] resources: []
 Task3 prev: [4] next: [1] resources: []
 Task1 prev: [2, 3] next: [7] resources: []
 Task7 prev: [1] next: [] resources: []""")
-        self.failUnlessEqual(w(i=3), {'z':60})
+        self.assertEqual(w(i=3), {'z':60})
 
     def test1b(self):
         pyutilib.workflow.reset_id_counter()
@@ -195,15 +195,15 @@ Task7 prev: [1] next: [] resources: []""")
         # Create workflow
         w = pyutilib.workflow.Workflow()
         w.add(A,loadall=False)
-        self.failUnlessEqual(str(w),"Workflow Task4:\nTask5 prev: [] next: [] resources: []")
+        self.assertEqual(str(w),"Workflow Task4:\nTask5 prev: [] next: [] resources: []")
 
     def test1a(self):
         pyutilib.workflow.reset_id_counter()
         # Create workflow
         w = pyutilib.workflow.Workflow()
-        self.failUnlessEqual(str(w),"Workflow Task1:\nTask2 prev: [] next: [] resources: []")
+        self.assertEqual(str(w),"Workflow Task1:\nTask2 prev: [] next: [] resources: []")
         w.add(pyutilib.workflow.task.NoTask)
-        self.failUnlessEqual(str(w),"Workflow Task1:\nTask2 prev: [] next: [] resources: []")
+        self.assertEqual(str(w),"Workflow Task1:\nTask2 prev: [] next: [] resources: []")
 
     @unittest.skipIf( is_python24or25, "There is a slight (space) formatting difference from pformat from Python2.6.  Skipping test.")
     def test2(self):
@@ -258,7 +258,7 @@ Task7 prev: [1] next: [] resources: []""")
                       'Ready': 'False',
                       'Task': '1',
                       'Value': 'None'}}}"""
-        self.failUnlessEqual(repr(A), base)
+        self.assertEqual(repr(A), base)
 
     @unittest.skipIf( is_python24or25, "There is a slight (space) formatting difference from pformat from Python2.6.  Skipping test.")
     def test3(self):
@@ -304,8 +304,8 @@ Task7 prev: [1] next: [] resources: []""")
          'Task': '1',
          'Value': 'None'}}"""
 
-        self.failUnlessEqual(str(A.inputs), inputs_base)
-        self.failUnlessEqual(str(A.outputs), outputs_base)
+        self.assertEqual(str(A.inputs), inputs_base)
+        self.assertEqual(str(A.outputs), outputs_base)
 
 
     @unittest.skipIf( is_python24or25, "There is a slight (space) formatting difference from pformat from Python2.6.  Skipping test.")
@@ -360,8 +360,8 @@ Task7 prev: [1] next: [] resources: []""")
                       'Task': '1',
                       'Value': 'None'}}}"""
 
-        self.failUnlessEqual(A.inputs['x'].get_value(), 2)
-        self.failUnlessEqual(repr(A), base)
+        self.assertEqual(A.inputs['x'].get_value(), 2)
+        self.assertEqual(repr(A), base)
 
     def test5(self):
         pyutilib.workflow.reset_id_counter()
@@ -395,7 +395,7 @@ Task7 prev: [1] next: [] resources: []""")
         w = pyutilib.workflow.Workflow()
         w.add(A)
         w.set_options(['--i=3','--a=2'])
-        self.failUnlessEqual(w(), {'z':334})
+        self.assertEqual(w(), {'z':334})
         # This doesn't work, since we can't merge options that aren't
         # in groups.  The soln is to move to argparse, but I'll save that for later
         #w.print_help()
@@ -422,7 +422,7 @@ Task7 prev: [1] next: [] resources: []""")
         OUTPUT = open(currdir+'test5b.out','w')
         print >>OUTPUT, repr(w)
         OUTPUT.close()
-        self.failUnlessFileEqualsBaseline(currdir+'test5b.out', currdir+'test5b.txt')
+        self.assertFileEqualsBaseline(currdir+'test5b.out', currdir+'test5b.txt')
 
     def test_error1(self):
         pyutilib.workflow.reset_id_counter()
